@@ -50,6 +50,25 @@ void	config(int argc, char **argv)
 				/* 0 fifo  */
 				cmdmode = atoi (pnt);
 			}
+			else if (!memcmp (buff, "TRUST_PORT", 10))
+			{
+				AuthPort = htons(atoi(pnt));
+			}
+			else if (!memcmp (buff, "TRUST_DB_IN_PORT", 16))
+			{
+				dbInPort = htons(atoi(pnt));
+			}
+			else if (!memcmp (buff, "TRUST_DB_OUT_PORT", 17))
+			{
+				dbOutPort = htons(atoi(pnt));
+			}
+                        else if (!memcmp (buff, "SERVER_NAME", 11))
+                        {
+				len = strlen(pnt);
+				if (len > 16) len = 16;
+                                memset (ServerName, 0x00, 16);
+                                memcpy (ServerName, pnt, len);
+                        }
 		}
 	}
 	fclose (config_file);
